*Ralifore: Raff Libraries for Effective Data Visualization
****Make your data visualization more attractive and effective with Ralifore.\ 
Built from Matplotlib and Seaborn which will make it easy for you to tell \
stories with data effectively. Can be used for exploratory analysis, \
explanatory analysis, and even reporting at once. Enjoy the convenience of \
creating effective graphics with Ralifore: Raff Libraries for Effective Data \
Visualization.

Log:
V 0.0.1 - Greeting function hello libraries:v
V 0.0.2 - add Axis styler barchart, ticks value barchart, 
          Title subtitle & ticks labelling, preattentive color barchart
V 0.0.3 - add